@@ -1,27 +1,25 @@
 use crate::simple::search_index::SearchIndex;
-use std::clone::Clone;
-use std::cmp::{Eq, PartialEq};
-use std::fmt::Debug;
-use std::hash::Hash;
+use std::cmp::Ord;
 
 // -----------------------------------------------------------------------------
 
-impl<K: Clone + Debug + Eq + Hash + PartialEq> SearchIndex<K> {
+impl<K: Ord> SearchIndex<K> {
 
     // -------------------------------------------------------------------------
     //
-    /// An associated helper function that splits a `&str` into keywords using a
-    /// split pattern (`Vec` of `char`). This function will also filter-out
-    /// keywords that don't meet the defined length constraints.
+    /// An associated helper method that splits a `&str` into keywords using a
+    /// split pattern (`Vec<char>`). This method will also perform case
+    /// conversion if necessary, and filter-out keywords that don't meet the
+    /// defined length constraints.
 
     pub(crate) fn string_keywords(
         &self,
         string: &str,
-        allow_string_as_keyword: bool,
+        use_string_as_keyword: bool,
     ) -> Vec<String> {
 
-        // If case sensitivity set, leave case intact. Otherwise, convert each
-        // keyword to lower case:
+        // If case sensitivity set, leave case intact. Otherwise, convert the
+        // entire string to lower case:
         let string = match self.case_sensitive {
             true => string.to_string(),
             false => string.to_lowercase(),
@@ -29,7 +27,7 @@ impl<K: Clone + Debug + Eq + Hash + PartialEq> SearchIndex<K> {
 
         // Split the the field text / string into keywords:
         let mut keywords: Vec<String> = if let Some(split_pattern) = &self.split_pattern {
-            // Use the split pattern (`Vec` of `char`) to split the `String` into
+            // Use the split pattern (a `Vec<char>`) to split the `String` into
             // keywords and filter the results:
             string
                 // Split the `String` into smaller strings / keywords on
@@ -44,20 +42,20 @@ impl<K: Clone + Debug + Eq + Hash + PartialEq> SearchIndex<K> {
                     chars >= self.minimum_keyword_length && chars <= self.maximum_keyword_length
                 }) // filter
                 // Copy string from reference:
-                .map(|str_ref| str_ref.to_string())
+                .map(String::from)
                 // Collect all keywords into a `Vec`:
                 .collect()
         } else {
             // Split pattern was set to `None`, so do not split the `String`
             // into keywords. Return an empty `Vec` instead:
-            vec![]
+            Vec::new()
         };
 
         // If the option is enabled, store the field text / entire string itself
-        // as a keyword for autocompletion purposes:
+        // as a keyword. This feature is for autocompletion purposes:
         if let Some(maximum_string_length) = self.maximum_string_length {
             // Only keep the string if it's shorter than the maximum:
-            if allow_string_as_keyword && string.chars().count() <= maximum_string_length {
+            if use_string_as_keyword && string.chars().count() <= maximum_string_length {
                 // Add field text / entire string to the keyword `Vec`:
                 keywords.push(string);
             } // if
